import { RouterModule } from '@angular/router';
import { Component, OnInit } from '@angular/core';
import { CommonModule } from '@angular/common';
import { MatDialog } from '@angular/material/dialog';
import { MatButtonModule } from '@angular/material/button';
import { MatListModule } from '@angular/material/list';
import { MatIconModule } from '@angular/material/icon';
import { MatBadgeModule } from '@angular/material/badge';
import { MatCardModule } from '@angular/material/card';
import { MatToolbarModule } from '@angular/material/toolbar';

@Component({
  imports: [
    RouterModule,
    CommonModule,
    MatButtonModule,
    MatListModule,
    MatIconModule,
    MatBadgeModule,
    MatCardModule,
    MatToolbarModule
  ],
  templateUrl: './page-crm-home.html',
  styleUrl: './page-crm-home.scss',
  selector: 'page-crm-home',
  standalone: true,
})
export class PageCrmHome implements OnInit {
  constructor(private dialog: MatDialog) {}

  // Font Awesome 图标
  icons = {
    faBrain: 'brain', 
    faBell: 'bell', 
    faUser: 'user', 
    faArrowRight: 'arrow-right', 
    faRobot: 'robot', 
    faComments: 'comments', 
    faDatabase: 'database', 
    faUserTie: 'user-tie', 
    faTimes: 'times', 
    faHistory: 'history', 
    faStar: 'star', 
    faChartLine: 'chart-line', 
    faFileAlt: 'file-alt', 
    faBullhorn: 'bullhorn'
  };

  // 状态变量
  unreadMessagesCount: number = 3;

  // 数据
  motivationalText: string = '每一次对话都是展现专业的机会，每一次练习都在提升成功的概率！今天，让AI成为您最强大的销售伙伴';
  stats = {
    practiceCount: 42,
    strategyCount: 28,
    satisfactionRate: 96
  };
  
  features = {
    virtualPractice: { count: 12, score: 85 },
    speechStrategy: { count: 8, effectiveness: 92 },
    dataTraining: { size: '3.2TB', accuracy: 98 },
    customerProfile: { count: 24 }
  };
  
  userStats = {
    practiceCount: 12,
    beatPercentage: 86
  };
  
  user = {
    name: '张明',
    role: '高级销售经理'
  };
  
  messages = [
    { title: '新的陪练挑战', preview: '您有一个新的虚拟陪练挑战等待完成，主题：高端客户价格谈判', time: '10分钟前', unread: true },
    { title: '话术策略更新', preview: '您收藏的"投诉处理"话术策略已更新至3.2版本', time: '1小时前', unread: true },
    { title: '陪练成绩通知', preview: '您最近的虚拟陪练成绩为92分，超过89%的销售同事', time: '昨天', unread: false },
    { title: '团队周报', preview: '本周团队陪练报告已生成，点击查看详细分析', time: '2天前', unread: false },
    { title: '系统维护通知', preview: '系统将于本周六凌晨2:00-4:00进行维护升级', time: '3天前', unread: false }
  ];
  
  trainings = [
    { title: '高端客户价格谈判', date: '2023-10-15', difficulty: '⭐⭐⭐', score: 92 },
    { title: '首次接触技巧', date: '2023-10-12', difficulty: '⭐⭐', score: 85 },
    { title: '投诉处理模拟', date: '2023-10-08', difficulty: '⭐⭐⭐', score: 88 },
    { title: '长期合作谈判', date: '2023-10-02', difficulty: '⭐⭐⭐⭐', score: 78 }
  ];

  motivationalPhrases = [
    "每一次对话都是展现专业的机会，每一次练习都在提升成功的概率！今天，让AI成为您最强大的销售伙伴",
    "每一次拒绝都是离成功更近一步！",
    "卓越的销售不是推销产品，而是解决问题！",
    "今天的练习，明天的签约！",
    "客户的需求是您成功的地图，AI是您的导航仪！",
    "专业来自准备，成功源于坚持！",
    "您不是一个人在战斗，AI是您最强大的后援！"
  ];

  ngOnInit(): void {
    this.updateMotivationalText();
    setInterval(() => this.updateMotivationalText(), 10000);
    setInterval(() => this.updateStats(), 5000);
  }

  updateMotivationalText(): void {
    const randomIndex = Math.floor(Math.random() * this.motivationalPhrases.length);
    this.motivationalText = this.motivationalPhrases[randomIndex];
  }

  updateStats(): void {
    this.stats.practiceCount = Math.floor(Math.random() * 20 + 35);
    this.stats.strategyCount = Math.floor(Math.random() * 15 + 20);
    this.stats.satisfactionRate = Math.floor(Math.random() * 5 + 94);
  }

  
   

    
  }

 
  

  
