import { Component, OnInit, ViewChild } from '@angular/core';
import { RouterModule } from '@angular/router';
import { CommonModule } from '@angular/common';
import { FontAwesomeModule } from '@fortawesome/angular-fontawesome';
import { LoginModalComponent } from './login.component';
import { RegisterModalComponent } from './register.component';
import { 
  faBrain, faBell, faUser, faRobot, faComments, 
  faDatabase, faUserTie, faTimes, faHistory, faStar, 
  faChartLine, faFileAlt, faBullhorn, faUserCircle,
  faFire, faTrophy, faCheck
} from '@fortawesome/free-solid-svg-icons';
import { CloudUser } from '../../../../lib/ncloud';

@Component({
  imports: [RouterModule, CommonModule, FontAwesomeModule, LoginModalComponent, RegisterModalComponent],
  templateUrl: './page-crm-home.html',
  styleUrls: ['./page-crm-home.scss'],
  selector: 'page-crm-home',
  standalone: true,
})
export class PageCrmHome implements OnInit {
  // Font Awesome 图标
  icons = {
    faBrain, faBell, faUser, faRobot, faComments, 
    faDatabase, faUserTie, faTimes, faHistory, faStar, 
    faChartLine, faFileAlt, faBullhorn, faUserCircle,
    faFire, faTrophy, faCheck
  };

  // 弹窗控制变量
  showLoginModal: boolean = false;
  showRegisterModal: boolean = false;
  loginError: string = '';
  registerError: string = '';

  // 当前用户信息（包含扩展字段）
  currentUser: any = null;
  isLoggedIn: boolean = false;
  loadingProfile: boolean = false; // 新增：加载状态

  // 弹窗状态
  showMessagePopup: boolean = false;
  showProfilePopup: boolean = false;
  selectedMessage: any = null;
  unreadMessagesCount: number = 0;

  // 数据
  motivationalText: string = '每一次对话都是展现专业的机会，每一次练习都在提升成功的概率！今天，让AI成为您最强大的销售伙伴';
  
  features = [
    {
      id: 'virtual-practice',
      title: '虚拟陪练',
      description: '与AI客户进行真实销售对话练习，提升沟通技巧',
      icon: 'fas fa-robot',
      statIcon: 'fas fa-history',
      stat1: '86次练习',
      stat2: '92%得分',
      hasNotification: true
    },
    {
      id: 'speech-strategy',
      title: '话术决策',
      description: '智能生成最佳沟通策略，应对各种销售场景',
      icon: 'fas fa-comments',
      statIcon: 'fas fa-star',
      stat1: '34个策略',
      stat2: '89%有效'
    },
    {
      id: 'data-training',
      title: '数据训练',
      description: '上传销售数据训练AI模型，优化决策能力',
      icon: 'fas fa-database',
      statIcon: 'fas fa-chart-line',
      stat1: '1.2GB',
      stat2: '95%准确'
    },
    {
      id: 'customer-profile',
      title: '客户画像',
      description: '生成详细客户分析报告，洞察客户需求',
      icon: 'fas fa-user-tie',
      statIcon: 'fas fa-file-alt',
      stat1: '28份',
      stat2: '更新中'
    }
  ];

  messages = [
    { 
      id: 1,
      title: '新的陪练挑战', 
      content: '您有一个新的虚拟陪练挑战等待完成，主题：高端客户价格谈判。请尽快完成以获得最佳学习效果。',
      time: '10分钟前', 
      unread: true 
    },
    { 
      id: 2,
      title: '话术策略更新', 
      content: '您收藏的"投诉处理"话术策略已更新至3.2版本，包含了最新的客户反馈数据。',
      time: '1小时前', 
      unread: true 
    },
    { 
      id: 3,
      title: '系统维护通知', 
      content: '系统将于本周六凌晨2:00-4:00进行维护升级，期间将无法使用服务。',
      time: '昨天', 
      unread: true 
    },
    { 
      id: 4,
      title: '陪练成绩通知', 
      content: '您最近的虚拟陪练成绩为92分，超过89%的销售同事，继续保持！',
      time: '2天前', 
      unread: true 
    },
    { 
      id: 5,
      title: '团队周报', 
      content: '本周团队陪练报告已生成，点击查看详细分析。',
      time: '3天前', 
      unread: true 
    }
  ];
  
  user = {
    username: '张明',
    role: '高级销售经理',
    age: 32,
    birthDate: '1991-05-15',
    trainingCount: 86
  };

  motivationalPhrases = [
    "每一次对话都是展现专业的机会，每一次练习都在提升成功的概率！今天，让AI成为您最强大的销售伙伴",
    "每一次拒绝都是离成功更近一步！",
    "卓越的销售不是推销产品，而是解决问题！",
    "今天的练习，明天的签约！",
    "客户的需求是您成功的地图，AI是您的导航仪！",
    "专业来自准备，成功源于坚持！",
    "您不是一个人在战斗，AI是您最强大的后援！"
  ];

  @ViewChild(LoginModalComponent) loginModal!: LoginModalComponent;
  @ViewChild(RegisterModalComponent) registerModal!: RegisterModalComponent;

// 在 PageCrmHome 类中添加（建议放在 logout 方法下方）
async loadUserProfile() {
  this.loadingProfile = true; // 开始加载
  try {
    const cloudUser = new CloudUser();
    const currentUser = await cloudUser.current(); // 获取当前用户
    
    if (currentUser && currentUser.sessionToken) {
      this.isLoggedIn = true;
      // 绑定完整用户信息（包含注册时的扩展字段）
      this.currentUser = {
        username: currentUser.get('username') || '用户',
        role: currentUser.get('role') || '销售',
        // 扩展字段（注册时填写的信息）
        age: currentUser.get('age') || '未设置',   // 年龄
        birthDate: currentUser.get('birthDate') || '未设置', // 出生日期
        position: currentUser.get('position') || '未设置',   // 职位
        // 系统字段
        trainingCount: currentUser.get('trainingCount') || 0
      };
      // 更新 user 对象，确保页面数据同步
      this.user = {
        username: this.currentUser.username,
        role: this.currentUser.position,
        age: this.currentUser.age,
        birthDate: this.currentUser.birthDate,
        trainingCount: this.currentUser.trainingCount
      };
    }
  } catch (error) {
    console.error('加载用户信息失败:', error);
    this.currentUser = null;
    this.isLoggedIn = false;
  } finally {
    this.loadingProfile = false; // 结束加载
  }
}






  private modalOpenCount = 0;
  private modalCloseReason: string = '';

  ngOnInit(): void {
    this.updateUnreadCount();
    this.updateMotivationalText();
    this.loadUserProfile(); // 初始化加载用户信息
    
    setInterval(() => this.updateMotivationalText(), 10000);
  }

  updateMotivationalText(): void {
    const randomIndex = Math.floor(Math.random() * this.motivationalPhrases.length);
    this.motivationalText = this.motivationalPhrases[randomIndex];
  }

  async logout(): Promise<void> {
    const cloudUser = new CloudUser();
    await cloudUser.logout();
    this.isLoggedIn = false;
    this.currentUser = null;
    this.user = {
      username: '访客',
      role: '未登录用户',
      age: 0,
      birthDate: '',
      trainingCount: 0
    };
    this.toggleProfilePopup();
  }

  toggleMessagePopup(): void {
    this.showMessagePopup = !this.showMessagePopup;
    if (this.showMessagePopup) {
      this.updateUnreadCount();
    }
  }

  // 优化：打开个人信息弹窗时刷新数据
  toggleProfilePopup(): void {
    this.showProfilePopup = !this.showProfilePopup;
    if (this.showProfilePopup && this.isLoggedIn) {
      this.loadUserProfile(); // 重新加载最新信息
    }
  }

  showMessageDetail(message: any, event?: Event): void {
    if (event) event.stopPropagation();
    this.selectedMessage = message;
    if (message.unread) {
      message.unread = false;
      this.updateUnreadCount();
    }
  }

  closeMessageDetail(): void {
    this.selectedMessage = null;
  }

  markMessageAsRead(message: any, event: Event): void {
    event.stopPropagation();
    if (message.unread) {
      message.unread = false;
      this.updateUnreadCount();
    }
  }

  markAllAsRead(): void {
    this.messages.forEach(message => message.unread = false);
    this.updateUnreadCount();
  }

  markAsRead(message: any): void {
    if (message.unread) {
      message.unread = false;
      this.updateUnreadCount();
    }
  }

  updateUnreadCount(): void {
    this.unreadMessagesCount = this.messages.filter(m => m.unread).length;
  }

  navigateTo(featureId: string): void {
    console.log('导航至:', featureId);
  }

  openLoginModal(): void {
    this.showRegisterModal = false;
    if (this.loginModal) {
      this.loginModal.resetForm();
    }
    this.showLoginModal = true;
    this.modalOpenCount++;
    this.modalCloseReason = '';
    document.body.classList.add('modal-open');
  }

  openRegisterModal(): void {
    console.log('接收到注册模态框打开请求');
    this.showLoginModal = false;
    this.showRegisterModal = true;
    if (this.registerModal) {
      this.registerModal.resetForm();
    }
    console.log('打开注册模态框后状态:', {
      showLoginModal: this.showLoginModal,
      showRegisterModal: this.showRegisterModal
    });
    this.modalOpenCount++;
    this.modalCloseReason = '';
    document.body.classList.add('modal-open');
  }

  closeModals(reason: string = 'manual'): void {
    this.modalCloseReason = reason;
    if (this.showRegisterModal) {
      this.showRegisterModal = false;
      this.registerError = '';
    }
    if (this.showLoginModal) {
      this.showLoginModal = false;
      this.loginError = '';
    }
    this.modalOpenCount--;
    if (this.modalOpenCount <= 0) {
      this.modalOpenCount = 0;
      document.body.classList.remove('modal-open');
      setTimeout(() => {
        window.scrollTo(0, 0);
      }, 100);
    }
  }

  // 优化：登录成功后重新加载用户信息
  async handleLoginSuccess(): Promise<void> {
    this.closeModals('login-success');
    setTimeout(async () => {
      await this.loadUserProfile(); // 加载最新用户信息
      console.log('登录成功，用户信息:', this.currentUser);
    }, 300);
  }

  handleRegisterSuccess(): void {
    this.closeModals('register-success');
    setTimeout(() => {
      this.openLoginModal();
      if (this.loginModal) {
        this.loginModal.showSuccessMessage('注册成功，请登录');
      }
    }, 300);
  }
}