import { Component, Output, EventEmitter, Input, OnChanges, OnDestroy, AfterViewInit, ElementRef, HostListener } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormBuilder, FormGroup, ReactiveFormsModule, Validators } from '@angular/forms';
import { CloudUser } from '../../../../lib/ncloud';

@Component({
  selector: 'app-register-modal',
  standalone: true,
  imports: [CommonModule, ReactiveFormsModule],
  template: `
    <div class="modal-overlay" *ngIf="visible" (click)="onClose($event)">
      <div class="overlay-backdrop" (click)="onClose($event)"></div>
      
      <div class="modal-container" tabindex="-1" (click)="$event.stopPropagation()">
        <div class="modal-content">
          <div class="modal-header">
            <h2>注册账号</h2>
            <button class="close-btn" (click)="onClose($event)">&times;</button>
          </div>
          
          <form [formGroup]="registerForm" (ngSubmit)="onRegister($event)">
            <div class="form-group">
              <label for="username">用户名</label>
              <input 
                type="text" 
                id="username" 
                formControlName="username" 
                placeholder="请输入用户名"
                [ngClass]="{ 'error-border': username.touched && username.invalid }">
              <div class="error-message" *ngIf="username.touched && username.hasError('required')">
                用户名不能为空
              </div>
            </div>


            <div class="form-group">
                <label for="age">年龄</label>
                <input 
                  type="number" 
                  id="age" 
                  formControlName="age" 
                  placeholder="请输入你的年龄"
                  [ngClass]="{ 'error-border': age.touched && age.invalid }">
                <div class="error-message" *ngIf="age.touched && age.hasError('required')">
                  年龄不能为空
                </div>
                <div class="error-message" *ngIf="age.touched && (age.hasError('min') || age.hasError('max'))">
                  年龄需在 1 - 150 之间
                </div>
              </div>
            

              <div class="form-group">
                  <label for="birthDate">出生日期</label>
                  <input 
                    type="date" 
                    id="birthDate" 
                    formControlName="birthDate" 
                    [ngClass]="{ 'error-border': birthDate.touched && birthDate.invalid }">
                  <div class="error-message" *ngIf="birthDate.touched && birthDate.hasError('required')">
                    出生日期不能为空
                  </div>
                </div>

                <div class="form-group">
                  <label for="position">职位</label>
                  <input 
                    type="text" 
                    id="position" 
                    formControlName="position" 
                    placeholder="请输入你的职位"
                    [ngClass]="{ 'error-border': position.touched && position.invalid }">
                  <div class="error-message" *ngIf="position.touched && position.hasError('required')">
                    职位不能为空
                  </div>
                </div>
            <div class="form-group">
              <label for="password">密码</label>
              <input 
                type="password" 
                id="password" 
                formControlName="password" 
                placeholder="请输入密码（至少6位）"
                [ngClass]="{ 'error-border': password.touched && password.invalid }">
              <div class="error-message" *ngIf="password.touched && password.hasError('required')">
                密码不能为空
              </div>
              <div class="error-message" *ngIf="password.touched && password.hasError('minlength')">
                密码长度至少6位
              </div>
            </div>
            
            <div class="form-group">
              <label for="confirmPassword">确认密码</label>
              <input 
                type="password" 
                id="confirmPassword" 
                formControlName="confirmPassword" 
                placeholder="请再次输入密码"
                [ngClass]="{ 'error-border': confirmPassword.touched && (confirmPassword.invalid || registerForm.hasError('passwordMismatch')) }">
              <div class="error-message" *ngIf="confirmPassword.touched && confirmPassword.hasError('required')">
                请确认密码
              </div>
              <div class="error-message" *ngIf="confirmPassword.touched && registerForm.hasError('passwordMismatch')">
                两次输入的密码不一致
              </div>
            </div>
            
            <button 
              type="submit" 
              class="submit-btn" 
              [disabled]="registerForm.invalid || isLoading">
              {{ isLoading ? '注册中...' : '立即注册' }}
            </button>
            
            <div class="switch-link">
              已有账号？ 
              <button type="button" class="login-link" (click)="onSwitchToLogin($event)">
                立即登录
              </button>
            </div>
          </form>
          
          <div class="global-error-message" *ngIf="errorMessage">
            {{ errorMessage }}
          </div>
        </div>
      </div>
      <<!-- 注册表单底部添加 -->
<div style="color: red; margin-top: 10px;">
  <!-- 表单级错误 -->
  表单级错误：{{ registerForm.errors | json }}<br>
  
  <!-- 所有控件的错误 -->
  用户名错误：{{ username.errors | json }}<br>
  密码错误：{{ password.errors | json }}<br>
  确认密码错误：{{ confirmPassword.errors | json }}<br>
  年龄错误：{{ age.errors | json }}<br>
  出生日期错误：{{ birthDate.errors | json }}<br>
  职位错误：{{ position.errors | json }}<br>
</div>
    </div>
  `,
  styles: [`
    .modal-overlay {
      position: fixed;
      top: 0;
      left: 0;
      width: 100%;
      height: 100%;
      background-color: rgba(0, 0, 0, 0.5);
      display: flex;
      justify-content: center;
      align-items: center;
      z-index: 1000;
      overflow-y: auto;
      pointer-events: all;
      user-select: none;
      opacity: 0;
      animation: fadeInOverlay 0.3s forwards;
    }
    
    @keyframes fadeInOverlay {
      to { opacity: 1; }
    }
    
    .overlay-backdrop {
      position: absolute;
      top: 0;
      left: 0;
      width: 100%;
      height: 100%;
      background-color: rgba(0, 0, 0, 0.5);
      z-index: 1;
    }
    
    .modal-container {
      position: relative;
      z-index: 2;
      width: 90%;
      max-width: 400px;
      background-color: white;
      border-radius: 8px;
      box-shadow: 0 4px 20px rgba(0, 0, 0, 0.15);
      margin: 20px;
      outline: none;
      pointer-events: all;
      transform: scale(0.95);
      opacity: 0;
      animation: fadeInModal 0.3s forwards;
    }
    
    @keyframes fadeInModal {
      to {
        transform: scale(1);
        opacity: 1;
      }
    }
    
    .modal-header {
      padding: 20px;
      border-bottom: 1px solid #eee;
      display: flex;
      justify-content: space-between;
      align-items: center;
    }
    
    .modal-header h2 {
      margin: 0;
      font-size: 1.2rem;
      color: #333;
    }
    
    .close-btn {
      background: none;
      border: none;
      font-size: 1.5rem;
      color: #999;
      cursor: pointer;
      transition: color 0.2s;
    }
    
    .close-btn:hover {
      color: #333;
    }
    
    .modal-content {
      padding: 20px;
    }
    
    .form-group {
      margin-bottom: 15px;
    }
    
    .form-group label {
      display: block;
      margin-bottom: 5px;
      font-size: 0.9rem;
      color: #555;
    }
    
    .form-group input {
      width: 100%;
      padding: 10px;
      border: 1px solid #ddd;
      border-radius: 4px;
      box-sizing: border-box;
      font-size: 1rem;
      transition: border-color 0.2s;
    }
    
    .form-group input:focus {
      outline: none;
      border-color: #007bff;
    }
    
    .error-border {
      border-color: #dc3545 !important;
    }
    
    .error-message {
      color: #dc3545;
      font-size: 0.8rem;
      margin-top: 5px;
    }
    
    .submit-btn {
      width: 100%;
      padding: 10px;
      background-color: #007bff;
      color: white;
      border: none;
      border-radius: 4px;
      cursor: pointer;
      font-size: 1rem;
      transition: background-color 0.2s;
      margin-top: 10px;
      box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
    }
    
    .submit-btn:hover {
      background-color: #0069d9;
      box-shadow: 0 2px 8px rgba(0, 0, 0, 0.2);
    }
    
    .submit-btn:disabled {
      background-color: #6c757d;
      cursor: not-allowed;
      box-shadow: none;
    }
    
    .switch-link {
      text-align: center;
      margin-top: 15px;
      font-size: 0.9rem;
      color: #555;
    }
    
    .login-link {
      background: none;
      border: none;
      color: #007bff;
      cursor: pointer;
      text-decoration: underline;
      font-size: 0.9rem;
    }
    
    .login-link:hover {
      color: #0056b3;
    }
    
    .global-error-message {
      color: #dc3545;
      font-size: 0.9rem;
      text-align: center;
      margin-top: 15px;
      padding: 10px;
      background-color: #f8d7da;
      border-radius: 4px;
      opacity: 0;
      animation: fadeInError 0.3s forwards;
    }
    
    @keyframes fadeInError {
      to { opacity: 1; }
    }
  `]
})
export class RegisterModalComponent implements OnChanges, AfterViewInit, OnDestroy {
  @Input() visible: boolean = false;
  @Output() close = new EventEmitter<void>();
  @Output() switchToLogin = new EventEmitter<void>();
  @Output() registerSuccess = new EventEmitter<void>();

  registerForm: FormGroup;
  errorMessage: string = '';
  isLoading: boolean = false;
  private modalElement!: HTMLElement;
  private scrollTop: number = 0;

  constructor(private fb: FormBuilder, private elementRef: ElementRef) {
    this.registerForm = this.fb.group({
      username: ['', Validators.required],
      password: ['', [Validators.required, Validators.minLength(6)]],
      confirmPassword: ['', Validators.required],
        age: [null, [Validators.required, Validators.min(1), Validators.max(150)]], // 年龄
        birthDate: [null, Validators.required], // 出生日期
        position: ['', Validators.required] // 职位
    }, { validator: this.passwordMatchValidator });
  }

  ngAfterViewInit() {
    this.modalElement = this.elementRef.nativeElement.querySelector('.modal-container');
    if (this.visible) {
      this.focusModal();
    }
  }

  ngOnChanges() {
    if (this.visible) {
      this.disableBodyScroll();
      this.resetForm();
      setTimeout(() => this.focusModal(), 100);
    } else {
      this.enableBodyScroll();
    }
  }

  ngOnDestroy() {
    this.enableBodyScroll();
  }

  // 重置表单状态
  resetForm() {
    this.registerForm.reset();
    this.errorMessage = '';
    this.isLoading = false;
  }

  passwordMatchValidator(form: FormGroup) {
    const password = form.get('password')?.value;
    const confirmPassword = form.get('confirmPassword')?.value;
    return password === confirmPassword ? null : { passwordMismatch: true };
  }

  private focusModal() {
    if (this.modalElement) {
      this.modalElement.focus();
      const firstInput = this.modalElement.querySelector('input');
      if (firstInput) {
        (firstInput as HTMLElement).focus();
      }
    }
  }

  @HostListener('keydown.tab', ['$event'])
  onTabKey(event: Event) {
    const keyboardEvent = event as KeyboardEvent;
    
    if (!this.modalElement) return;
    
    const focusableElements = this.modalElement.querySelectorAll(
      'button, [href], input, select, textarea, [tabindex]:not([tabindex="-1"])'
    );
    
    if (focusableElements.length === 0) return;
    
    const firstElement = focusableElements[0] as HTMLElement;
    const lastElement = focusableElements[focusableElements.length - 1] as HTMLElement;
    
    if (keyboardEvent.shiftKey) {
      if (document.activeElement === firstElement) {
        lastElement.focus();
        keyboardEvent.preventDefault();
      }
    } else {
      if (document.activeElement === lastElement) {
        firstElement.focus();
        keyboardEvent.preventDefault();
      }
    }
  }

  private disableBodyScroll() {
    this.scrollTop = window.scrollY;
    document.body.style.overflow = 'hidden';
    document.body.style.position = 'fixed';
    document.body.style.top = `-${this.scrollTop}px`;
    document.body.style.width = '100%';
  }

  private enableBodyScroll() {
    document.body.style.overflow = '';
    document.body.style.position = '';
    document.body.style.top = '';
    document.body.style.width = '';
    window.scrollTo(0, this.scrollTop);
  }

 onClose(event: Event) {
  event.stopPropagation();
  if (this.modalElement) { // 增加非空判断，避免 modalElement 为 null 时报错
    this.modalElement.style.transform = 'scale(0.95)';
    this.modalElement.style.opacity = '0';
  }
  setTimeout(() => {
    this.visible = false;
    this.close.emit();
  }, 200);
}


  onSwitchToLogin(event: Event) {
    event.stopPropagation();
    
    // 添加切换动画
    this.modalElement.style.transform = 'scale(0.95)';
    this.modalElement.style.opacity = '0';
    
    setTimeout(() => {
      this.visible = false;
      this.switchToLogin.emit();
    }, 200);
  }

  async onRegister(event: Event) {
  event.preventDefault();
  if (this.registerForm.invalid || this.isLoading) {
     // 表单无效时触发表单验证
    Object.values(this.registerForm.controls).forEach(control => {
      control.markAsTouched(); // 标记为已触碰，触发错误提示
    });
    return;
  }

  this.isLoading = true;
  this.errorMessage = '';

  try {
    // 1. 获取表单中所有字段（包括新增的 name、age 等）
    const { username, password,  age, birthDate, position } = this.registerForm.value;
    const cloudUser = new CloudUser();
    
    // 2. 构造扩展数据（包含新增字段和原有字段）
    const additionalData = {
      role: 'sales',
      trainingCount: 0,
      age: Number(age), // 确保为数字类型
      birthDate: new Date(birthDate),
      position
    };

    // 3. 调用注册接口，传递所有数据
    const user = await cloudUser.signUp(username, password, additionalData);

    if (user) {
      this.registerSuccess.emit();
      this.visible = false;
    } else {
      this.errorMessage = '注册失败，请稍后重试';
    }
  } catch (error: any) {
    // 错误处理
    if (error.message.includes('username already exists')) {
      this.errorMessage = '该用户名已被注册，请更换其他用户名';
    } else {
      this.errorMessage = error?.message || '注册失败，请检查网络连接';
    }
    console.error('注册错误:', error);
  } finally {
    this.isLoading = false;
  }
}

  get username() { return this.registerForm.get('username')!; }
  get password() { return this.registerForm.get('password')!; }
  get confirmPassword() { return this.registerForm.get('confirmPassword')!; }
  // 在类的末尾添加（与其他 getter 方法并列）
  get age() { return this.registerForm.get('age')!; }         // 年龄控件
  get birthDate() { return this.registerForm.get('birthDate')!; } // 出生日期控件
  get position() { return this.registerForm.get('position')!; }   // 职位控件
}